#ifndef HEADER_HH_
#define HEADER_HH_
#include <string>
#include <iostream>
#include <fstream>  
namespace Header
{
  enum SURVEY { S70, PM, PH };
  inline SURVEY idSurvey(std::string file)
  {
    std::ifstream fin;
    fin.open(file.c_str(), std::ios::binary);
    char *hdr = new char[5];
    fin.read( hdr, 5*sizeof(char) );
    fin.close();
    hdr[4] = '\0';
    unsigned char compstring_s70[5] = {182, 'm', 'm', 219, 0};
    unsigned char compstring_pm[4] = {'P', 'M', 'D'};
    compstring_pm[3] = '\0';
    if(strcmp((const char*)compstring_s70,hdr)==0) return S70;
    if(strncmp((const char*)compstring_pm,hdr,3)==0) return PM;
  }

  enum ISMOVING { NOTGRID=0, POINT, MOVING, SCANNING };

  enum FIELDS 
    {CODE=0, VERSION, TAPENR, SCAN_CNTR, BLK_CNTR, 
     DATE, MJD, UT_STRT, LST_STRT, 
     COORD_TYPE, RA_STRT, DEC_STRT, GL_STRT, GB_STRT, 
     FEED_ANGLE, OBS_TIME, SCAN_RATE, SCAN_LEN, COMMENT, 
     NFILTER, CHANBW, NCHAN, FREQ_CHAN1, 
     SAMP_INT, SAMP_GRP, GRP_BLK, BLK_SEC, FDCNTRL, DATA_TYPE,
     UT, LST, RA, DEC, GL, GB, TEL_ZEN, TEL_AZ, 
     STATUS, ATTEN, TPOWER, NBLK_READ, SCAN_RATEL, SCAN_RATEB, 
     BYTE_GRP, NBEAM, IBEAM, PSRNAME, DATA_TWO, OBS_FILEN, 
     NBITS, DDM, NDDCH, MOVE, PNTERR, TREE, NSYS, 
     TELID, PANGLE, SMP_BSW, CAL_CYCLE, RESERVE
    };

  const int numKeywords = RESERVE + 1;


  class SurveySchema
  {
  public:
    SurveySchema(){};
    SurveySchema(SURVEY surveyType);
    SurveySchema(const SurveySchema& s){
    for(int i=0;i<numKeywords;i++) startPosition[i]  = s.startPosition[i];
    for(int i=0;i<numKeywords;i++) fieldLength[i]    = s.fieldLength[i];
    for(int i=0;i<numKeywords;i++) fieldDimension[i] = s.fieldDimension[i];
    };
    SurveySchema& operator= (const SurveySchema& s){
    for(int i=0;i<numKeywords;i++) startPosition[i]  = s.startPosition[i];
    for(int i=0;i<numKeywords;i++) fieldLength[i]    = s.fieldLength[i];
    for(int i=0;i<numKeywords;i++) fieldDimension[i] = s.fieldDimension[i];
    };
    virtual ~SurveySchema(){};
    int getStartPosition(int field){return startPosition[field];};
    int getFieldLength(int field){return fieldLength[field];};
    int getFieldDimension(int field){return fieldDimension[field];};
    template <class T> T readParameter(std::string headerString, int field,
				       int elementNumber = 0);
    class xBadSurvey{
    public:
      xBadSurvey(std::string s){surveyName=s;};
      virtual ~xBadSurvey(){};
      std::string getSurvey(){return surveyName;};
    private:
      std::string surveyName;
    };
 
  private:
    int startPosition[numKeywords];
    int fieldLength[numKeywords];
    int fieldDimension[numKeywords];
  };

}


#endif /*HEADER_HH_*/
