#ifndef PSRFITS_HH_
#define PSRFITS_HH_
#include <fitsio.h>
#include <string>
#include "Block.hh"
#include "Header.hh"

using namespace Block;
using namespace Header;

namespace FITS
{
	
  //	enum HDU = {PHU=1, HISTORY, DIG_STAT, DIG_CNTS, 

  enum STATE { OPEN, CLOSED }; 
	
  void FITSError(std::string function, int status);
  
  const int SUBINT_kw_nch_strt = 0;
  const std::string SUBINT_kw_int_type = "TIME";
  const std::string SUBINT_kw_int_unit = "SEC";
  const std::string PHU_kw_obs_mode = "SEARCH";
  const std::string PHU_kw_coord_md = "J2000.0";
  
  class PSRFits
  {
  public:
    PSRFits();
    PSRFits(std::string name);
    PSRFits(DataBlock &block);
    virtual ~PSRFits(){};
    bool isNewFile(){return newFile;};
    int openFile(DataBlock &block);
    int openFile(std::string name);
    void fixPSRFITS();
    int closeFile();
    STATE getFilestate(){return filestate;};
    void setFilestate(STATE S){filestate=S;};
    int gotoPHU();
    int gotoSubint();
    template <class T> int updateKeyword(std::string name, T value); 
    template <class T> int writeColumnValue(char *name, T value);
    int getColnum(char *name);
    long getNumRows();
    int startNewRow();
    void writePHU(DataBlock &block);
    void writeSubint(DataBlock &block);
    void startNewColumn();
    void writeColumnValue();
    void writeSupportArrays(DataBlock &block);
    void writeDataArray(DataBlock &block);
    

  private:
    fitsfile *fptr;
    bool newFile;
    STATE filestate;
  };

}
#endif /*PSRFITS_HH_*/
